@@ -12,6 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-def make_env(env_id, **kwargs):
-    raise Exception("metagym.make_env is deprecated. Please do \"import metagym.xxxenv\" and use gym.make instead")
+__version__ = '0.2.2.0'
\ No newline at end of file
