@@ -14,41 +14,18 @@
 
 from gym.envs.registration import register
 from l3c.mazeworld.envs import MazeWorldContinuous3D
-from l3c.mazeworld.envs import MazeWorldDiscrete3D
-from l3c.mazeworld.envs import MazeWorld2D
-from l3c.mazeworld.envs import MazeTaskSampler
+from l3c.mazeworld.envs import MazeTaskSampler, Resampler
 
 register(
-    id='mazeworld-continuous-3D-v0',
+    id='mazeworld-v2',
     entry_point='l3c.mazeworld:MazeWorldContinuous3D',
     kwargs={
         "enable_render": True,
         "render_scale": 480,
         "resolution": (256, 256),
         "max_steps": 5000,
-        "task_type": "SURVIVAL"
-    }
-)
-
-register(
-    id='mazeworld-discrete-3D-v0',
-    entry_point='l3c.mazeworld:MazeWorldDiscrete3D',
-    kwargs={
-        "enable_render": True,
-        "render_scale": 480,
-        "resolution": (256, 256),
-        "max_steps": 200,
-        "task_type": "SURVIVAL"
-    }
-)
-
-register(
-    id='mazeworld-2D-v0',
-    entry_point='l3c.mazeworld:MazeWorld2D',
-    kwargs={
-        "enable_render": True,
-        "max_steps": 200,
-        "view_grid": 1,
-        "task_type": "SURVIVAL"
+        "visibility_3D": 12.0,
+        "command_in_observation": False,
+        "action_space_type": "Discrete16" ,
     }
 )
